@@ -27,10 +27,10 @@
     unused_results
 )]
 
-use anyhow::{anyhow, Error as AnyhowError, Result};
+use eyre::{eyre, Result, WrapErr};
 use safe_network::node::{add_connection_info, set_connection_info, Config, Error, Node};
 use self_update::{cargo_crate_version, Status};
-use std::{io::Write, process};
+use std::{io::Write, process::exit};
 use structopt::{clap, StructOpt};
 use tokio::time::{sleep, Duration};
 use tracing::{self, error, info};
@@ -41,48 +41,37 @@ const BOOTSTRAP_RETRY_TIME: u64 = 3; // in minutes
 use safe_network::routing;
 
 /// Runs a Safe Network node.
-fn main() {
-    let sn_node_thread = std::thread::Builder::new()
+fn main() -> Result<()> {
+    color_eyre::install()?;
+
+    let handle = std::thread::Builder::new()
         .name("sn_node".to_string())
         .stack_size(16 * 1024 * 1024)
         .spawn(move || {
             let rt = tokio::runtime::Runtime::new()?;
             rt.block_on(run_node())?;
-            Ok::<(), AnyhowError>(())
-        });
+            Ok(())
+        })
+        .wrap_err("Failed to spawn node thread")?;
 
-    match sn_node_thread {
-        Ok(thread) => match thread.join() {
-            Ok(_) => {}
-            Err(err) => println!("Failed to run node: {:?}", err),
-        },
-        Err(err) => println!("Failed to run node: {:?}", err),
+    match handle.join() {
+        Ok(result) => result,
+        Err(error) => {
+            // thread panic errors cannot be converted to `eyre::Report` as they are not `Sync`, so
+            // the best thing to do is propagate the panic.
+            std::panic::resume_unwind(error)
+        }
     }
 }
 
 async fn run_node() -> Result<()> {
-    let config = match Config::new().await {
-        Ok(cfg) => cfg,
-        Err(e) => {
-            println!("Failed to create Config: {:?}", e);
-            exit(1);
-            return Ok(());
-        }
-    };
+    let config = Config::new().await?;
 
     if let Some(c) = &config.completions() {
-        match c.parse::<clap::Shell>() {
-            Ok(shell) => match gen_completions_for_shell(shell) {
-                Ok(buf) => {
-                    std::io::stdout().write_all(&buf).unwrap_or_else(|e| {
-                        println!("Failed to print shell completions. {}", e);
-                    });
-                }
-                Err(e) => println!("{}", e),
-            },
-            Err(e) => println!("Unknown completions option. {}", e),
-        }
-        // we exit program on both success and error.
+        let shell = c.parse().map_err(|err: String| eyre!(err))?;
+        let buf = gen_completions_for_shell(shell).map_err(|err| eyre!(err))?;
+        std::io::stdout().write_all(&buf)?;
+
         return Ok(());
     }
 
@@ -96,13 +85,10 @@ async fn run_node() -> Result<()> {
         Err(_) => {
             // we manually determine level filter instead of using tracing EnvFilter.
             let level_filter = config.verbose();
-            let module_log_filter = format!("{}={}", MODULE_NAME, level_filter.to_string());
-
-            EnvFilter::from_default_env().add_directive(
-                module_log_filter
-                    .parse()
-                    .map_err(|_| anyhow!("Could not parse module log filter"))?,
-            )
+            let module_filter = format!("{}={}", MODULE_NAME, level_filter)
+                .parse()
+                .wrap_err("BUG: invalid module filter constructed")?;
+            EnvFilter::from_default_env().add_directive(module_filter)
         }
     };
 
@@ -196,11 +182,10 @@ async fn run_node() -> Result<()> {
                 error!("{}", &message);
             }
             Err(e) => {
-                println!("Cannot start node due to error: {:?}. If this is the first node on the network \
-                 pass the local address to be used using --first. Exiting", e);
-                error!("Cannot start node due to error: {:?}. If this is the first node on the network \
-                 pass the local address to be used using --first. Exiting", e);
-                exit(1);
+                return Err(e).wrap_err(
+                    "Cannot start node. If this is the first node on the network pass the local \
+                    address to be used using --first",
+                );
             }
         }
         sleep(Duration::from_secs(BOOTSTRAP_RETRY_TIME * 60)).await;
@@ -222,22 +207,11 @@ async fn run_node() -> Result<()> {
             });
     }
 
-    match node.run(event_stream).await {
-        Ok(()) => {
-            exit(0);
-            Ok(())
-        }
-        Err(e) => {
-            println!("Cannot start node due to error: {:?}", e);
-            error!("Cannot start node due to error: {:?}", e);
-            exit(1);
-            Ok(())
-        }
-    }
-}
+    node.run(event_stream)
+        .await
+        .wrap_err("Node failed to start")?;
 
-fn exit(exit_code: i32) {
-    process::exit(exit_code);
+    Ok(())
 }
 
 fn update() -> Result<Status, Box<dyn (::std::error::Error)>> {
